import { csv, select,legendColor } from 'd3';
import { scatterPlot } from './scatterPlot';


const csvUrl = 'https://gist.githubusercontent.com/anushaanumula/85d1a14655cde3fc775af1a07289c1b4/raw/b267188d51f4f9292f55a69e1ee6fa00d9f0e244/PS4_Sales.csv';
																																																											 
		   
const parseRow = (d) => {
  d.RestofWorld = +d.RestofWorld;
  d.Japan = +d.Japan;
  d.Europe = +d.Europe;
  d.Global = +d.Global;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const xValue = (d) => d.Europe;
const yValue = (d) => d.Global;
const rxValue = (d) => d.RestofWorld;
const ryValue = (d) => d.Japan;
const gameValue = (d) => d.Game;
const colorValue = d => d.Game;
const colorLabel = 'Game';


const main = async () => {
  const data = await csv(csvUrl, parseRow);
  const x = xValue((d) => d.Global);
  const y = yValue((d) => d.RestofWorld);
  const marker = (d) => {
        	switch(d){
            case 'Japan':
              return 'red';
            case 'Europe':
              return 'green';
            default:
              return 'blue';
          }
        }
  
  const marks = data.map((d) => ({
          x: xValue((d) => d.Global),
          y: yValue((d) => d.RestofWorld),
          species: gameValue(d),
          color: marker(gameValue(d)),
        	rx: rxValue(d),
          ry: ryValue(d),
                      
        }));
  
  
//Defining scatterplot structure
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.Global)
    .yValue((d) => d.RestofWorld)
    .margin({
      top: 95,
      right: 100,
      bottom: 90,
      left: 95,

    })
    .radius(5);
  
  
 const g = svg.append('g')
          .attr('transform', `translate(${100},${100})`);

      const colorLegendG = g.append('g')
          .attr('transform', `translate(${100}, 150)`);





//Defining the shape and structure of data points  
svg
          .selectAll('circle')
          .data(marks)
          .join('circle')
          .attr('cx', (d) => d.x)
          .attr('cy', (d) => d.y)
        	.attr('fill', (d) => d.color)
        	.attr('rx', (d) => (d.rx))
        	.attr('ry', (d) => (d.ry));

     
    
  
  const columns = [
    'RestofWorld',
    'Japan',
    'Europe',
    'Global',
  ];

  
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);
				  
				   
					
		svg.selectAll('text').remove();
    svg.call(plot);
    
      colorLegendG.append('text')
          .attr('class', 'legend-label')
          .attr('x', -70)
          .attr('y', -230)
          .style("font-style","Bold")
          .style("stroke","blue")
          .text(colorLabel);

   
// Title
svg.append("text").attr("x", 450).attr("y", 20).text("PS4 Sales Scatterplot").style("font-size", "35px").attr("alignment-baseline","middle")

   
// Add labels in the legend
svg.append("text").attr("x", 150).attr("y", 40).text("Japan").style("font-size", "15px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 60).text("Europe").style("font-size", "15px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 80).text("Global").style("font-size", "15px").attr("alignment-baseline","middle")
  
    svg
        	.append("text")
        	.attr('transform', 'rotate(-90)')
        	.attr('x',0 - (height /2))
        	.attr("y",  height/12)
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
							  
        	.text("RestofWorld");
    
    // Add points for legend
    svg.append("circle").attr("cx",130).attr("cy",40).attr("r", 6).style("fill", "red")
		svg.append("circle").attr("cx",130).attr("cy",60).attr("r", 6).style("fill", "green")
		svg.append("circle").attr("cx",130).attr("cy",80).attr("r", 6).style("fill", "blue")
   // plot petal_width on x-axis
    if(i % columns.length==0) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  580 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
			.style("stroke","blue")				  
      		.text("RestofWorld");
     // plot sepal_width on x-axis
    else if(i % columns.length==1) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
			.style("stroke","blue")				  
      		.text("Japan");
     // plot petal_length on x-axis
    else if(i % columns.length==2) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
			.style("stroke","blue")				  
      		.text("Europe");
     // plot sepal_length on x-axis
       else 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
			.style("stroke","blue")				  
      		.text("Global");
    i++;
  }, 2000);// every 2 seconds change the visualization
};
main();